# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'bin',
 'wee_resources': 'bin/wee_resources',
 'weecfg': 'bin/weecfg',
 'weectllib': 'bin/weectllib',
 'weedb': 'bin/weedb',
 'weeimport': 'bin/weeimport',
 'weeplot': 'bin/weeplot',
 'weeutil': 'bin/weeutil',
 'weewx': 'bin/weewx',
 'weewx.drivers': 'bin/weewx/drivers'}

packages = \
['schemas',
 'wee_resources',
 'weecfg',
 'weectllib',
 'weedb',
 'weeimport',
 'weeplot',
 'weeutil',
 'weewx',
 'weewx.drivers']

package_data = \
{'': ['*'],
 'wee_resources': ['docs/*',
                   'docs/assets/images/*',
                   'docs/assets/javascripts/*',
                   'docs/assets/javascripts/lunr/*',
                   'docs/assets/javascripts/lunr/min/*',
                   'docs/assets/javascripts/workers/*',
                   'docs/assets/stylesheets/*',
                   'docs/changes/*',
                   'docs/copyright/*',
                   'docs/css/*',
                   'docs/custom/*',
                   'docs/custom/appendix/*',
                   'docs/custom/cheetah/*',
                   'docs/custom/custom_reports/*',
                   'docs/custom/database/*',
                   'docs/custom/derived/*',
                   'docs/custom/drivers/*',
                   'docs/custom/extensions/*',
                   'docs/custom/image_generator/*',
                   'docs/custom/localization/*',
                   'docs/custom/multiple_bindings/*',
                   'docs/custom/options_ref/*',
                   'docs/custom/service_engine/*',
                   'docs/custom/units/*',
                   'docs/devnotes/*',
                   'docs/examples/*',
                   'docs/images/*',
                   'docs/js/*',
                   'docs/quickstarts/*',
                   'docs/quickstarts/debian/*',
                   'docs/quickstarts/pip/*',
                   'docs/quickstarts/redhat/*',
                   'docs/quickstarts/suse/*',
                   'docs/quickstarts/v5-upgrade/*',
                   'docs/report_scheduling/*',
                   'docs/search/*',
                   'docs/sle/*',
                   'docs/support/*',
                   'docs/usersguide/*',
                   'docs/usersguide/backing-up-weewx/*',
                   'docs/usersguide/installing-weewx/*',
                   'docs/usersguide/mysql-mariadb-config/*',
                   'docs/usersguide/running-weewx/*',
                   'docs/usersguide/system-requirements/*',
                   'docs/usersguide/troubleshooting-guide/*',
                   'docs/usersguide/webserver-integration/*',
                   'docs/usersguide/weewx-config-file/*',
                   'docs/usersguide/weewx-config-file/data-bindings/*',
                   'docs/usersguide/weewx-config-file/databases/*',
                   'docs/usersguide/weewx-config-file/databasetypes/*',
                   'docs/usersguide/weewx-config-file/engine/*',
                   'docs/usersguide/weewx-config-file/general/*',
                   'docs/usersguide/weewx-config-file/stations-config/*',
                   'docs/usersguide/weewx-config-file/stdarchive/*',
                   'docs/usersguide/weewx-config-file/stdcalibrate-config/*',
                   'docs/usersguide/weewx-config-file/stdconvert-config/*',
                   'docs/usersguide/weewx-config-file/stdqc-config/*',
                   'docs/usersguide/weewx-config-file/stdreport-config/*',
                   'docs/usersguide/weewx-config-file/stdrestful-config/*',
                   'docs/usersguide/weewx-config-file/stdtimesynch/*',
                   'docs/usersguide/weewx-config-file/stdwxcalculate-config/*',
                   'docs/usersguide/where/*',
                   'docs/utilities/*',
                   'docs/weectl/*',
                   'docs/weectl/extension/*',
                   'docs/weectl/station/*']}

modules = \
['wee_database',
 'wee_debug',
 'wee_device',
 'wee_import',
 'wee_reports',
 'weectl',
 'weewxd',
 'wunderfixer']
install_requires = \
['CT3>=3.1,<4.0',
 'Pillow>=5.2',
 'PyMySQL>=1.0,<2.0',
 'configobj>=5.0,<6.0',
 'pyephem>=3.7,<4.0',
 'pyserial>=3.4,<4.0',
 'pyusb>=1.0.2,<2.0.0',
 'six>=1,<2']

entry_points = \
{'console_scripts': ['wee_database = wee_database:main',
                     'wee_debug = wee_debug:main',
                     'wee_device = wee_device:main',
                     'wee_import = wee_import:main',
                     'wee_reports = wee_reports:main',
                     'weectl = weectl:main',
                     'weewxd = weewxd:main',
                     'wunderfixer = wunderfixer:main']}

setup_kwargs = {
    'name': 'weewx',
    'version': '5.0.0a21',
    'description': 'The WeeWX weather software system',
    'long_description': '![CI workflow](https://github.com/weewx/weewx/actions/workflows/ci.yaml/badge.svg)\n\n# [WeeWX](http://www.weewx.com)\n*Open source software for your weather station*\n\n## Description\n\nThe WeeWX weather system is written in Python and runs on Linux, MacOSX,\nSolaris, and *BSD.  It runs exceptionally well on a Raspberry Pi.  It generates\nplots, HTML pages, and monthly and yearly summary reports, which can be\nuploaded to a web server. Thousands of users worldwide!\n\nSee the WeeWX website for [examples](http://weewx.com/showcase.html) of web\nsites generated by WeeWX, and a [map](http://weewx.com/stations.html) of\nstations using WeeWX.\n\n* Robust and hard-to-crash\n* Designed with the enthusiast in mind\n* Simple, easy to understand internal design that is easily extended (Python skills recommended)\n* Python 3.7 or greater\n* Large ecosystem of 3rd party extensions\n* Internationalized language support\n* Localized date/time support\n* Support for US and metric units\n* Support for multiple skins\n* Support sqlite and MySQL\n* Extensive almanac information\n* Uploads to your website via FTP, FTPS, or rsync\n* Uploads to online weather services\n\nSupport for many online weather services, including:\n\n* The Weather Underground\n* CWOP\n* PWSweather\n* WOW\n* AWEKAS\n* Open Weathermap\n* WeatherBug\n* Weather Cloud\n* Wetter\n* Windfinder\n\nSupport for over 70 types of hardware including, but not limited to:\n\n* Davis Vantage Pro, Pro2, Vue, Envoy;\n* Oregon Scientific WMR100, WMR300, WMR9x8, and other variants;\n* Oregon Scientific LW300/LW301/LW302;\n* Fine Offset WH10xx, WH20xx, and WH30xx series (including Ambient, Elecsa, Maplin, Tycon, Watson, and others);\n* Fine Offset WH23xx, WH4000 (including Tycon TP2700, MiSol WH2310);\n* Fine Offset WH2600, HP1000 (including Ambient Observer, Aercus WeatherSleuth, XC0422);\n* LaCrosse WS-23XX and WS-28XX (including TFA);\n* LaCrosse GW1000U bridge;\n* Hideki TE923, TE831, TE838, DV928 (including TFA, Cresta, Honeywell, and others);\n* PeetBros Ultimeter;\n* RainWise CC3000 and MKIII;\n* AcuRite 5-in-1 via USB console or bridge;\n* Argent Data Systems WS1;\n* KlimaLogg Pro;\n* New Mountain;\n* AirMar 150WX;\n* Texas Weather Instruments;\n* Dyacon;\n* Meteostick;\n* Ventus W820;\n* Si1000 radio receiver;\n* Software Defined Radio (SDR);\n* One-wire (including Inspeed, ADS, AAG, Hobby-Boards).\n\nSee the [hardware list](http://www.weewx.com/hardware.html) for a complete list\nof supported stations, and for pictures to help identify your hardware!  The\n[hardware comparison](http://www.weewx.com/hwcmp.html) shows specifications for\nmany different types of hardware, including some not yet supported by WeeWX.\n\n## Install\n\nInstall either using `pip`, or package installers (Debian, Red Hat, SuSE).\n\nFor current and previous releases:\n\n[http://weewx.com/downloads](http://weewx.com/downloads)\n\n## Documentation and Support\n\nGuides for installation, upgrading, and customization:\n\n[http://weewx.com/docs.html](http://weewx.com/docs.html)\n\nThe wiki includes user-contributed extensions and suggestions at:\n\n[https://github.com/weewx/weewx/wiki](https://github.com/weewx/weewx/wiki)\n\nCommunity support can be found at:\n\n[https://groups.google.com/group/weewx-user](https://groups.google.com/group/weewx-user)\n\n<h2>Licensing</h2>\n\nWeeWX is licensed under the GNU Public License v3.\n',
    'author': 'Tom Keffer',
    'author_email': 'tkeffer@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://weewx.com',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'py_modules': modules,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
